@@ -9,6 +9,6 @@ NULL
 ## quiets concerns of R CMD check re: the .'s that appear in pipelines
 if (getRversion() >= "2.15.1") {
   utils::globalVariables(c(
-    ".", "result", "data", "SYMBOL"
+    ".", "result", "data", "SYMBOL", "chart", "meta", "regularMarketPrice"
   ))
 }
